@@ -1,10 +1,10 @@
-class MDString(object):
-    string = None
+from .mdobject import MDObject
+
+class MDString(MDObject):
+    string: str = None
     def __init__(self, string: str):
         self.string = string
     def __str__(self):
         return self.string
-    def _repr_markdown_(self):
-        return self.__str__()
     def __repr__(self):
         return '<MDString>'
